#!/bin/bash


# Default directory (used for testing)
DEFAULT_SOURCE="/appl/local/climatedt/input_data/applications/AQUA_O-25.1_v1.0/" # Note that source gets a trailing / in the rysnc line anyway

# I can specify the source as an argument, if no argument is provided, use the default source
SOURCE="${1:-$DEFAULT_SOURCE}"

# Needs to match the source directory, both using trailing /
DESTINATION="transfer1:/gpfs/scratch/ehpc01/input_data/applications/"

# Extract source folder name from the path, for naming the log files
SOURCE_NAME=$(basename "$SOURCE")

# Log files
LOG_DIR="/users/hearnesh/data_admin/transfer_logs"
TIMESTAMP=$(date +'%Y%m%d_%H%M%S')
LOG_FILE="$LOG_DIR/${SOURCE_NAME}_t_log_$TIMESTAMP.txt"
ERROR_LOG_FILE="$LOG_DIR/${SOURCE_NAME}_t_err_log_$TIMESTAMP.txt"
VALIDATION_LOG_FILE="$LOG_DIR/${SOURCE_NAME}_val_log_$TIMESTAMP.txt"

# Ensure log directory exists
mkdir -p "$LOG_DIR"

# Move to the parent directory of the source (to prevent full path being transferred)
cd "$(dirname "$SOURCE")"


# Perform the transfer and log it
echo "Starting rsync transfer..." 

nohup time rsync -aPR --stats --delete "$(basename "$SOURCE")/" "$DESTINATION" > "$LOG_FILE" 2>> "$ERROR_LOG_FILE" &
#nohup rsync --delete "$(basename "$SOURCE")/" "$DESTINATION" > "$LOG_FILE" 2>> "$ERROR_LOG_FILE" &
RSYNC_PID=$!

echo "Transfer started in background. Check logs at:"
echo "  - Progress: $LOG_FILE"
echo "  - Errors:   $ERROR_LOG_FILE"
echo "Use 'tail -f $LOG_FILE' to monitor."

# Wait for the rsync process to finish
wait "$RSYNC_PID"

echo "Transfer complete at $(date)."

#echo "Transfer complete. Check $LOG_FILE for details and $ERROR_LOG_FILE for errors."

# Perform rsync validation. This does not transfer any files, it just  uses checksums
echo "Starting rsync validation..." > "$VALIDATION_LOG_FILE"
#rsync -aPRc --dry-run --verbose --itemize-changes "$(basename "$SOURCE")" "$DESTINATION" > "$VALIDATION_LOG_FILE" 2>> "$VALIDATION_ERROR_LOG_FILE" &
nohup rsync -aPRc --dry-run --delete "$(basename "$SOURCE")/" "$DESTINATION" &>> "$VALIDATION_LOG_FILE"  # Both output and errors go to the same log file


# End message
echo "Validation complete. Check $VALIDATION_LOG_FILE for details. If the files are the same in both repos, then there should not be any more text after sending incremental files "
