#!/bin/bash

# Default directory (used for testing)
DEFAULT_SOURCE="/appl/local/climatedt/input_data/applications/"

# I can specify the source as an argument, if no argument is provided, use the default source
SOURCE="${1:-$DEFAULT_SOURCE}"
DESTINATION="transfer1:/gpfs/scratch/ehpc01/input_data/" 

# Extract source folder name from the path - for naming the log files
SOURCE_NAME=$(basename "$SOURCE")

# Log files
LOG_DIR="/users/hearnesh/data_admin/transfer_logs"
TIMESTAMP=$(date +'%Y%m%d_%H%M%S')
VALIDATION_LOG_FILE="$LOG_DIR/${SOURCE_NAME}_val_log_$TIMESTAMP.txt"

# Ensure log directory exists
mkdir -p "$LOG_DIR"

# Move to the parent directory of the source (to prevent full path being transferred)
cd "$(dirname "$SOURCE")"

# Perform rsync validation. This does not transfer any files, it just  uses checksums
echo "Starting rsync validation..." > "$VALIDATION_LOG_FILE"
nohup rsync -aPRc --dry-run --delete "$(basename "$SOURCE")/" "$DESTINATION" &>> "$VALIDATION_LOG_FILE"  # Both output and errors go to the same log file

# End message
echo "Validation complete. Check $VALIDATION_LOG_FILE for details. If the files are the same in both repos, then there should not be any more text after sending incremental files"

# Note: I need to manually check if the validation was succesful by checking that there 
# is no text in the log files printed after "sending incremental files" and no errors. 
